% Create a sinusoidal signal
Fs = 1000;                    % Sampling frequency
t = 0:1/Fs:0.999;              % Time vector

% Signal parameters
A1 = 1;                        % Amplitude of sinusoid 1
f1 = 50;                       % Frequency of sinusoid 1

% Create a noisy sinusoidal signal
noise = 0.1 * randn(size(t)); % Random Gaussian noise with mean 0 and standard deviation 0.1
noisy_signal = A1 * sin(2*pi*f1*t) + noise;

% Compute the power spectrum of the noisy signal
power_spectrum = fft(noisy_signal);

% Normalize the power spectrum
normalized_power_spectrum = power_spectrum ./ length(power_spectrum);
normalized_power_spectrum = abs(normalized_power_spectrum);

% Plot the original signal, the noisy signal, and the power spectrum
figure;
subplot(3,1,1);
plot(t, A1 * sin(2*pi*f1*t));
title('Original Signal');
xlabel('Time (s)');
ylabel('Amplitude');

subplot(3,1,2);
plot(t, noisy_signal);
title('Noisy Signal');
xlabel('Time (s)');
ylabel('Amplitude');

subplot(3,1,3);
plot(abs(fftshift(normalized_power_spectrum)));
title('Power Spectrum of Noisy Signal');
xlabel('Frequency (Hz)');
ylabel('Power');
